<?php
/**
 *
 * AntiAdblock extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2018 Picaron
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace Picaron\AntiAdblock\acp;

/**
* @package acp
*/
class acp_antiadblock_module
{
    /** @var \phpbb\config\config */
    protected $config;

    /** @var \phpbb\config\db_text */
    protected $config_text;

    /** @var \phpbb\request\request */
    protected $request;

    /** @var \phpbb\template\template */
    protected $template;

    /** @var \phpbb\user */
    protected $user;

    /** @var string phpbb_root_path */
    protected $phpbb_root_path;

    /** @var string */
    public $u_action;

    /** @var string */
    public $new_config = array();


    function main($id, $mode)
    {
        global $config, $config_text, $request, $template, $user, $phpbb_root_path, $phpbb_container, $antiadblock_lang_user;

        $this->config_text = $phpbb_container->get('config_text');

        $action = $request->variable('action', '');
        $submit = (isset($_POST['submit'])) ? true : false;

        $form_key = 'acp_antiadblock';
        add_form_key($form_key);

            // Asign inicial vars
            $display_vars_ini = array(
                'title' => 'ACP_ANTIADBLOCK',
                'vars'  => array(
                    'legend' => 'GENERAL_OPTIONS',
                    'antiadblock_active'        => array('lang' => 'ACP_ANTIADBLOCK_ACTIVE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => false),
                    'antiadblock_cookie'        => array('lang' => 'ACP_ANTIADBLOCK_COOKIE', 'validate' => 'int:5:800', 'type' => 'number:5:1800', 'explain' => true, 'append' => '  ' . $user->lang('ACP_UNI_DELAY')),
                    'antiadblock_banner'        => array('lang' => 'ACP_DISPLAY_ANTIADBLOCK_SHOW', 'validate' => 'int', 'type' => false, 'method' => false, 'explain' => false),
                    'antiadblock_can_closed'    => array('lang' => 'ACP_ANTIADBLOCK_CAN_CLOSED', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => true),
                    'antiadblock_delay'         => array('lang' => 'ACP_DISPLAY_ANTIADBLOCK_TIME', 'validate' => 'int:1:20', 'type' => 'number:1:20', 'explain' => true, 'append' => '  ' . $user->lang('ACP_UNI_DELAY')),                
                )
            );

            // Load inicial vars
            $this->new_config['antiadblock_active']     = $config['antiadblock_active'];
            $this->new_config['antiadblock_cookie']     = $config['antiadblock_cookie'];
            $this->new_config['antiadblock_banner']     = $config['antiadblock_banner'];
            $this->new_config['antiadblock_can_closed'] = $config['antiadblock_can_closed'];
            $this->new_config['antiadblock_delay']      = $config['antiadblock_delay'];         

        // Loading defined languages
        $cadena = $this->config_text->get('antiadblock_languages');
        $idiomas_ini = !empty($cadena) ? unserialize(json_decode($cadena, true)) : array();

        // First position lang of admin
        if (in_array($antiadblock_lang_user, $idiomas_ini)) { $idiomas[] = $antiadblock_lang_user; }
        foreach ($idiomas_ini as $ii) { if ($ii != $antiadblock_lang_user) { $idiomas[] = $ii; } }

        $display_vars_lng = array('title' => 'ACP_ANTIADBLOCK');
        foreach ($idiomas as $i)
        {
            // Asign language vars
            $display_vars_lng['vars']['legend_'.$i] = $user->lang('ACP_ANTIADBLOCK_PACK_LANGUAGE', $i);

            if ($i != 'en') // Not can delete
            {
                $display_vars_lng['vars']['antiadblock_delete_'.$i] = array('lang' => 'ACP_ANTIADBLOCK_DELETE', 'validate' => 'bool', 'type' => 'radio:yes_no', 'explain' => true);
            }

            $display_vars_lng['vars']['antiadblock_ini_'.$i] = array('lang' => 'ACP_ANTIADBLOCK_REQUEST_INI', 'validate' => 'antiadblock_ini_'.$i, 'type' => 'textarea:5:70', 'explain' => true);
            $display_vars_lng['vars']['antiadblock_disable_'.$i] = array('lang' => 'ACP_ANTIADBLOCK_REQUEST_DISABLE', 'validate' => 'antiadblock_disable_'.$i, 'type' => 'textarea:5:70', 'explain' => true);
            $display_vars_lng['vars']['antiadblock_over_'.$i] = array('lang' => 'ACP_ANTIADBLOCK_CLOSE_OVER', 'validate' => 'string', 'type' => 'text:72:250', 'explain' => true);
            $display_vars_lng['vars']['antiadblock_help_'.$i] = array('lang' => 'ACP_ANTIADBLOCK_TAKE_HELP', 'validate' => 'string', 'type' => 'text:72:250', 'explain' => true);
            $display_vars_lng['vars']['antiadblock_help_url_'.$i] = array('lang' => 'ACP_ANTIADBLOCK_TAKE_HELP_URL', 'validate' => 'string', 'type' => 'url:72:250', 'explain' => true);

            // Load language vars
            $this->new_config['antiadblock_delete_'.$i] = 0;
            $this->new_config['antiadblock_ini_'.$i] = $this->config_text->get('antiadblock_ini_'.$i);
            $this->new_config['antiadblock_disable_'.$i] = $this->config_text->get('antiadblock_disable_'.$i);
            $this->new_config['antiadblock_over_'.$i] = $this->config_text->get('antiadblock_over_'.$i);
            $this->new_config['antiadblock_help_'.$i] = $this->config_text->get('antiadblock_help_'.$i);
            $this->new_config['antiadblock_help_url_'.$i] = $this->config_text->get('antiadblock_help_url_'.$i);
        }

        // New language
            // Asign language vars
            $display_vars_new['vars']['legend_new'] = $user->lang('ACP_ANTIADBLOCK_PACK_LANGUAGE', $user->lang('ACP_ANTIADBLOCK_PACK_LANGUAGE_NEW'));
            $display_vars_new['vars']['antiadblock_name_new'] = array('lang' => 'ACP_ANTIADBLOCK_NAME_NEW', 'validate' => 'string', 'type' => 'text:12:12', 'explain' => true);
            $display_vars_new['vars']['antiadblock_ini_new'] = array('lang' => 'ACP_ANTIADBLOCK_REQUEST_INI', 'validate' => 'antiadblock_ini_new', 'type' => 'textarea:5:70', 'explain' => true);
            $display_vars_new['vars']['antiadblock_disable_new'] = array('lang' => 'ACP_ANTIADBLOCK_REQUEST_DISABLE', 'validate' => 'antiadblock_disable_new', 'type' => 'textarea:5:70', 'explain' => true);
            $display_vars_new['vars']['antiadblock_over_new'] = array('lang' => 'ACP_ANTIADBLOCK_CLOSE_OVER', 'validate' => 'string', 'type' => 'text:72:250', 'explain' => true);
            $display_vars_new['vars']['antiadblock_help_new'] = array('lang' => 'ACP_ANTIADBLOCK_TAKE_HELP', 'validate' => 'string', 'type' => 'text:72:250', 'explain' => true);
            $display_vars_new['vars']['antiadblock_help_url_new'] = array('lang' => 'ACP_ANTIADBLOCK_TAKE_HELP_URL', 'validate' => 'string', 'type' => 'url:72:250', 'explain' => true);

        $my_cfg_array = (isset($_REQUEST['config'])) ? utf8_normalize_nfc($request->variable('config', array('' => ''), true)) : $this->new_config;
        $error = array();

        // Any new language???
        if (isset($my_cfg_array['antiadblock_name_new']) && $my_cfg_array['antiadblock_name_new'] != '')
        {
            $new_language = trim(str_replace(' ', '_', $my_cfg_array['antiadblock_name_new']));
            if (in_array($new_language, $idiomas))
            {
                $error[] = $user->lang('ACP_ANTIADBLOCK_LANGUAGE_EXIST', $new_language);
            }

            $total = array_merge($display_vars_lng['vars'] + $display_vars_new['vars'] + $display_vars_ini['vars']);
        } else {
            $total = array_merge($display_vars_lng['vars'] + $display_vars_ini['vars']);
        }

        // We validate the complete config and config_text if whished
        validate_config_vars($total, $my_cfg_array, $error);

        if ($submit && !check_form_key($form_key))
        {
            $error[] = $user->lang['FORM_INVALID'];
        }

        // Do not write values if there is an error
        if (sizeof($error))
        {
            $submit = false;
        }

        // Save all vars
        if ($submit)
        {
            // Save vars
            foreach ($total as $config_name => $null)
            {
                if (strpos($config_name, 'delete') !== false || strpos($config_name, 'legend') !== false || strpos($config_name, 'forums') !== false) { continue; }

                if (isset($config[$config_name]))
                {
                    // Save ini language vars
                    $config->set($config_name, $my_cfg_array[$config_name]);
                } elseif (strpos($config_name, 'new') === false)
                {
                    // Save existing language vars
                    $this->config_text->set($config_name, $my_cfg_array[$config_name]);
                } elseif (strpos($config_name, 'name_new') === false)
                {
                    if (isset($new_language) && $new_language != '' && !in_array($new_language, $idiomas))
                    {
                        // Save new language vars
                        $cad = substr ($config_name, 0, strlen($config_name) - 3);
                        $this->config_text->set($cad.$new_language, $my_cfg_array[$config_name]);
                    }
                }
            }

            // Save new array languages
            if (isset($new_language) && $new_language != '' && !in_array($new_language, $idiomas))
            {
                $idiomas[] = $new_language;
                $this->config_text->set('antiadblock_languages', json_encode(serialize($idiomas)));
            }

            // Delete language
            $idiomas_no_del = array('en');  // Not can delete
            $ok_del = false;

            foreach ($idiomas as $i)
            {
                if ($i == 'en')  // Not can delete
                {
                    continue;
                }
                if (isset($my_cfg_array['antiadblock_delete_'.$i]) && $my_cfg_array['antiadblock_delete_'.$i] == 1)
                {
                    $ok_del = true;

                    $this->config_text->delete('antiadblock_ini_'.$i);
                    $this->config_text->delete('antiadblock_help_'.$i);
                    $this->config_text->delete('antiadblock_help_url_'.$i);
                    $this->config_text->delete('antiadblock_disable_'.$i);
                    $this->config_text->delete('antiadblock_over_'.$i);
                } else {
                    $idiomas_no_del[] = $i;
                }
            }

            // Save new array languages after deletes
            if ($ok_del)
            {
                $this->config_text->set('antiadblock_languages', json_encode(serialize($idiomas_no_del)));
            }

            // Save log
            $phpbb_log = $phpbb_container->get('log');
            $phpbb_log->add('admin', $user->data['user_id'], $user->ip, 'LOG_CONFIG_' . strtoupper($mode));

            trigger_error($user->lang['CONFIG_UPDATED'] . adm_back_link($this->u_action));
        }

        // Printing subpages
        $this->antiadblock_output_page($display_vars_ini['vars']);
        $this->antiadblock_output_page($display_vars_new['vars']);
        $this->antiadblock_output_page($display_vars_lng['vars']);

        $this->tpl_name = 'acp_antiadblock';
        $this->page_title = $display_vars_ini['title'];

        $template->assign_vars(array(
            'L_TITLE'                    => $user->lang[$display_vars_ini['title']],
            'L_TITLE_EXPLAIN'            => $user->lang[$display_vars_ini['title'] . '_EXPLAIN'],
            'L_ACP_ANTIADBLOCK_VERSION'  => $user->lang['ACP_ANTIADBLOCK_VERSION'],
            'SLIDE_ANTIADBLOCK_VERSION'  => isset($config['version_antiadblock']) ? $config['version_antiadblock'] : false,
            'S_ERROR'                    => (sizeof($error)) ? true : false,
            'ERROR_MSG'                  => implode('<br /><br />', $error),
            'U_ACTION'                   => $this->u_action)
        );
    }

    // Printing pages
    public function antiadblock_output_page($item)
    {
        global $template, $user;

        foreach ($item as $config_key => $vars)
        {
            if (!is_array($vars) && strpos($config_key, 'legend') === false)
            {
                continue;
            }

            if (strpos($config_key, 'legend') !== false)
            {
                $template->assign_block_vars('options', array(
                    'S_LEGEND'      => true,
                    'LEGEND'        => (isset($user->lang[$vars])) ? $user->lang[$vars] : $vars)
                );

                continue;
            }
            $type = explode(':', $vars['type']);

            $l_explain = '';
            if ($vars['explain'] != false)
            {
                $l_explain = (isset($user->lang[$vars['lang'] . '_EXPLAIN'])) ? $user->lang[$vars['lang'] . '_EXPLAIN'] : $vars['explain'];
            }

            $content = build_cfg_template($type, $config_key, $this->new_config, $config_key, $vars);

            if (empty($content))
            {
                continue;
            }

            $template->assign_block_vars('options', array(
                'KEY'           => $config_key,
                'TITLE'         => (isset($user->lang[$vars['lang']])) ? $user->lang[$vars['lang']] : $vars['lang'],
                'S_EXPLAIN'     => $vars['explain'],
                'TITLE_EXPLAIN' => $l_explain,
                'CONTENT'       => $content,
                )
            );

            unset($item[$config_key]);
        }
    }
}
?>