<?php
/**
 *
 * AntiAdblock extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2018 Picaron
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace Picaron\AntiAdblock\event;

/**
 * Event listener
 */
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
    /** @var \phpbb\config\config */
    protected $config;

    /** @var \phpbb\config\db_text */
    protected $config_text;

    /** @var \phpbb\user */
    protected $user;

    /** @var \phpbb\template\template */
    protected $template;

    /** @var \phpbb\db\driver\driver_interface */
    protected $db;

    /** @var \phpbb\auth\auth */
    protected $auth;

    /** @var \phpbb\request\request */
    protected $request;

    /** @var string */
    protected $phpbb_root_path;

    /** @var string */
    protected $phpEx;

    /**
    * Constructor
    *
    * @param \phpbb\config\config               $config
    * @param \phpbb\config\db_text              $config_text
    * @param \phpbb\user                        $user
    * @param \phpbb\template\template           $template
    * @param \phpbb\db\driver\driver_interface  $db
    * @param \phpbb\auth\auth                   $auth
    * @param \phpbb\request\request             $request
    * @param string                             $phpbb_root_path
    * @param string                             $phpEx
    *
    */
    public function __construct(
        \phpbb\config\config $config,
        \phpbb\config\db_text $config_text,
        \phpbb\user $user,
        \phpbb\template\template $template,
        \phpbb\db\driver\driver_interface $db,
        \phpbb\auth\auth $auth,
        \phpbb\request\request $request,
        $phpbb_root_path,
        $phpEx
    )
    {
        $this->config               = $config;
        $this->config_text          = $config_text;
        $this->user                 = $user;
        $this->template             = $template;
        $this->db                   = $db;
        $this->auth                 = $auth;
        $this->request              = $request;
        $this->phpbb_root_path      = $phpbb_root_path;
        $this->phpEx                = $phpEx;
    }

    /**
     * Assign functions defined in this class to event listeners in the core
     *
     * @return array
     * @static
     * @access public
     */
    static public function getSubscribedEvents()
    {
        return array(
            'core.user_setup'                               => 'load_language_on_setup',
            'core.page_footer'                              => 'page_footer',
            'core.build_config_template'                    => 'build_config_template',
            'core.validate_config_variable'                 => 'validate_config_variable',
            'core.permissions'                              => 'permissions',
        );
    }

    public function load_language_on_setup($event)
    {
        global $antiadblock_lang_user;

        $lang_set_ext = $event['lang_set_ext'];
        $lang_set_ext[] = array(
            'ext_name' => 'Picaron/AntiAdblock',
            'lang_set' => 'lng_antiadblock',
        );
        $event['lang_set_ext'] = $lang_set_ext;
        $antiadblock_lang_user = $event['user_lang_name'];
    }

    /**
     * Execute code and/or overwrite page_footer()
     *
     * @return null
     * @access public
     */
    public function page_footer($event)
    {
        global $config, $antiadblock_lang_user;

        $antiblock_html_elements = array(0=>'div', 1=>'center', 2=>'span', 3=>'b', 4=>'i', 5=>'font', 6=>'strong');
        $layer_id = chr(98 + mt_rand(0,24)) . substr(md5(time()), 0, 3);
        $eti_noscript = $antiblock_html_elements[array_rand($antiblock_html_elements)];
        $eti_mensaje = $antiblock_html_elements[array_rand($antiblock_html_elements)];

        $implode = implode("','", array_merge(array_rand(array_flip(array('ads300Bottom','advertisement-728x90','annoying_ad','ads','AD_CONTROL_22','ADsmallWrapper','Ad3TextAd','AdArea','AdBanner_F1','AdDetails_InsureWith','AdRectangle','AdSkyscraper','AdSpacing','AdTargetControl1_iframe','AdsContent','AdsRight','Ads_BA_CAD_box','Advertorials','AdvertsBottomR','BANNER_300x250','BodyAd','ContentAdPlaceHolder2','CornerAd','FooterAd','GoogleAd3','HOME_TOP_RIGHT_BOXAD','Home_AdSpan','Journal_Ad_300','LeftAd1','LowerContentAd','MainSponsoredLinks','OverrideAdArea','PREFOOTER_LEFT_BOXAD','PageLeaderAd','SectionAd300-250','SidebarAdContainer','TextLinkAds','TopAdDiv','VM-footer-adspace','VM-header-adspace','YahooAdParentContainer','_ads','ad-120x60Div','ad-250','ad-300x250','ad-376x280','ad-728x90-top0','ad-article','ad-banner-1','ad-footprint-160x600','ad-front-footer','ad-globalleaderboard','ad-img','ad-leaderboard','ad-left-sidebar-ad-1','ad-list-row','ad-lrec','ad-mpu2','ad-mpu2-spot','ad-right-sidebar-ad-1','ad-right-sidebar-ad-2','ad-slug-wrapper','ad-small-banner','ad-space','ad-space-1','ad-space-big','ad-splash','ad-text','ad-wrap-right','ad-wrapper1','ad-yahoo-simple','ad125TL','ad300x60','ad300x600','ad526x250','ad90','adBanner10','adBanner120x600','adBanner2','adBanner336x280','adBannerTable','adBlockTop','adBlocks','adCirc300X200','adContainer_2','adFiller','adFps','adGoogleText','adInteractive1','adLB','adLabel','adLeaderTop','adMonster1','adOuter','adPlacer','adPosOne','adSenseModule','adSenseWrapper','adShortTower','adSky','adSkyscraper','adSpace11','adSpace14','adSpace16','adSpace17','adSpace21','adSpace6','adSpace8','adSpacer','adTile','adTop1','ad_300b','ad_300c','ad_300x100_m_c','ad_300x250','ad_300x90','ad_468x60','ad_728_foot','ad_940','ad_B','ad_F','ad_I','ad_J','ad_N','ad_YieldManager-728x90','ad_anchor','ad_banner_top','ad_banners','ad_bellow_post','ad_block_2','ad_category_middle','ad_center_monster','ad_container_0','ad_container_marginal','ad_global_header2','ad_hdr_2','ad_lrec','ad_newsletter','ad_post_300','ad_replace_div_0','ad_replace_div_1','ad_ros_tower','ad_rr_1','ad_sense_help','ad_sidebar1','ad_sidebar3','ad_skyscraper_text','ad_slot_leaderboard','ad_top_holder','ad_tp_banner_2','ad_video_belowPlayer','adbanner','adbanner-home-right','adbanner-middle','adbig','adcolumnwrapper','adcontainsm','adcontent1','adfooter','adiframe1_iframe','adimg','adlayer_back','adleaderboard_flex','adleft','adposition-FPMM','adrectanglea_flex','adright2','adrighthome','ads-leaderboard1','ads-top','ads-wrapper','ads120','ads300','ads315','ads728bottom','adsDiv5','ads_belowforumlist','ads_catDiv','ads_footer','ads_notice','ads_text','ads_top','ads_watch_top_square','adsection','adsense-2','adsense-bottom','adsense-sidebar','adsenseLeft','adserv','adskinleft','adskinright','adskintop','adsleft1','adsmiddle','adspace_header','adspot-1','adspot-2b','adspot-300x250-pos-1','adspot-a','adspot_220x90','adspot_300x250','adsquare','adtagfooter','adtech_takeover','adv-300','adv-middle','adv-midroll','adv-preroll','adv300top','adv768x90','adv_mpu1','adv_top_banner_wrapper','adver3','advert-boomer','advert-display','advert-leaderboard','advert-links-bottom','advert_box','advert_home01','advert_sky','advertisediv','advertisement3','advertisementHeaderBottom','advertising-banner','advertising-control','advertising2','advertisingTop','advertisment-horizontal','adverts-top-right','advt','adwhitepaperwidget','adxSponLinkA','adxtop','adzerk1','adzoneheader','affinityBannerAd','alert_ads','article_box_ad','bannerAdFrame','banner_ad_module','banner_topad','bb_ad_container','bbo_ad1','bg-footer-ads','bg_YieldManager-160x600','bigAd1','bigadbox','bigadspot','block-ad_cube-1','block_advertisement','blog-advert','blog_ad_opa','blox-big-ad-bottom','blox-halfpage-ad','blox-tower-ad','bottom-ad-container','bottom-ad-wrapper','bottomad_table','bottomads','box-ads-small-1','box-googleadsense-1','box1ad','box_ad','box_advertisement','box_advertisment','boxad2','button_ads','centerads','channel_ad','channel_ads','circ_ad','cnnRR336ad','col3_advertising','colRightAd','column4-google-ads','comments-ad-container','common_right_lower_player_adspace','container-topleftads','containerMrecAd','contentTopAds2','content_bottom_ad','contentads','coverads','ctl00_ContentRightColumn_RightColumn_Ad2_BanManAd','ctl00_LHTowerAd','ctl00_MasterHolder_IBanner_adHolder','ctl00_TowerAd','ctl00_cphMain_hlAd2','ctl00_ctl00_ctl00_Main_Main_SideBar_MPSideAd','ctl00_ctrlAdvert8_iframeAdvert','cubead-2','currencies-sponsored-by','custom-advert-leadboard-spacer','dItemBox_ads','dcadSpot-Leader','dcadSpot-LeaderFooter','detail_page_vid_topads','divAdvertisement','divBottomad2','evotopTen_advert','ex-ligatus','featured_ad_links','first-300-ad','flash_ads_1','footer-ad','footer-ads','footer-advert','footerAdDiv','footerAds','footerAdverts','footer_ad_01','footer_ad_cloud','fr_ad_center','frame_admain','front_ad728','front_mpu','fw-advertisement','ga_300x250','gallery-random-ad','game-info-ad','gglads','gm-ad-lrec','google-ads-header','googleAdArea','googleAdBottom','google_ad','google_ads_aCol','google_ads_frame1','google_ads_frame1_anchor','google_ads_frame2_anchor','googlesponsor','gpt-ad-skyscraper','gpt-ad-story_rectangle3','gsyadtopload','half-page-ad','hd-banner-ad','head-ad-1','headAd','header-ad-left','header-ads','headerAds','header_ad_728_90','header_advertisement_top','headeradbox','headeradsense','hl-sponsored-results','home-advert-module','home-rectangle-ad','home-top-ads','homepage-ad','hometop_234x60ad','hottopics-advert','hp-mpu','hp-right-ad','hp_ad300x250','i_ads_table','icePage_SearchLinks_AdRightDiv','icePage_SearchResults_ads4_SponsoredLink','imu_ad_module','iwad','landing-adserver','lapho-top-ad-1','layerAds_layerDiv','layerad','leader-board-ad','leaderBoardAd','leaderad','leaderboard-ad','left_ads','lg-banner-ad','localAds','main-advert1','main_rec_ad','mastAd','mastAdvert','mastercardAd','media_ad','mid-ad300x250','midRightTextAds','mid_ad_div','mid_ad_title','mid_mpu','mid_roll_ad_holder','middle-ad','moogleAd','mos-adCarouselContainer','mpuDiv','mpu_text_ad','n_sponsor_ads','natadad300x250','national_microlink_ads','nationalad','nba160PromoAd','nbaLeft600Ad','nbcAd300x250','newads','ng_rtcol_ad','ovadsense','pageAds','pagelet_netego_ads','panelAd','pcworldAdBottom','pcworldAdTop','pod-ad-video-page','premium_ad','product-adsense','publicGoogleAd','qm-ad-big-box','realEstateAds','rhs_ads','rhsadvert','right-ad-skin','right-featured-ad','right-uppder-adverts-container','rightAdsDiv','rightBoxAdvertisement','rightad','rightadContainer','rightcolumn_300x250ad','righttop-adverts','rr_MSads','search-sponsored-links','searchAdSenseBox','searchAdSkyscraperBox','secondBoxAdContainer','section-blog-ad','servfail-ads','sideBarAd','side_sky_ad','sideads','sideadtop-to','sidebar-125x125-ads-below-index','sidebar-ad-space','sidebar-ad-wrap','sidebarAdvert','sidebar_ad_widget','sidebaradpane','site-ad-container','site-leaderboard-ads','sky_ad','skyads','skyscrapeAd','some-ads','sponsored-links','sponsored-listings','sponsored-resources','sponsored1','sponsoredBox1','sponsoredSiteSidebar','sponsored_head','sponsoredwellcontainertop','sponsorlink','spotlightad','squareAds','srp_adsense-top','start_middle_container_advertisment','story-ad-b','story-leaderboard-ad','subpage-ad-right','subpage-ad-top','template_ad_leaderboard','text-ads','text-link-ads','textad','textad_block','thefooterad','third_party_ads','tilia_ad','tmglBannerAd','top-advertisement','topAd728x90','topAdvBox','topAdvert','top_ad-sense','topadbar','topadblock','topadzone','topsponsored','toptextad','tourSponsoredLinksContainer','txfPageMediaAdvertVideo','undergameAd','upper-ads','vap_adsense-top','video_overlay_ad','view_ads_bottom_bg','view_ads_top_bg','wXcds12-ad','wall_advert','weatherad','wf_SingleAd','wrapperAdsTopLeft','y708-ad-ysm','yahoo_ads','ybf-ads','yn-gmy-ad-lrec','ysm_ad_iframe','tads.c','tadsb.c','topstuff > #tads')), 7), array("ad", "ads", "adsense")));

        // Adding cookie for delay the execution of extension
        if ($config['antiadblock_cookie'] < 11)
        {
            $show = true;
        } else {
            if ($this->request->variable($config['cookie_name'] . '_AntiAdblock', '', true, \phpbb\request\request_interface::COOKIE) != 'acceso')
            {
                $this->user->set_cookie('AntiAdblock', 'acceso', time() + $config['antiadblock_cookie']);
                $show = true;
            } else {
                $show = false;
            }
        }

        // SHOW warning for user permission - Note: User permission prevails over other options
        ($this->auth->acl_get('u_show_antiadblock')) ? '': $show = false;

        // SHOW warning in forums with permission
        $forum_id =  (int) $this->request->variable('f', '');
        if ($forum_id > 0) { ($this->auth->acl_get('f_show_antiadblock', $forum_id)) ? '': $show = false; }

        // Loading defined languages
        $cadena = $this->config_text->get('antiadblock_languages');
        $idiomas = !empty($cadena) ? unserialize(json_decode($cadena, true)) : array();
        in_array($antiadblock_lang_user, $idiomas) ? $mi_lng = $antiadblock_lang_user : $mi_lng = 'en';

        // Asign vars to Template
        $buscar                             = array(chr(13).chr(10), "\r\n", "\n", "\r");
        $reemplazar                         = array("<br>", "<br>", "<br>", "<br>");
        $variable['layer_id']               = $layer_id;
        $variable['eti_mensaje']            = $eti_mensaje;
        $variable['implode']                = $implode;
        $variable['closed']                 = $config['antiadblock_can_closed'] == 1 ? true : false;
        $variable['modo']                   = $config['antiadblock_banner'];
        $variable['delay']                  = $config['antiadblock_delay'];
        $variable['lng_request_ini']        = str_ireplace($buscar, $reemplazar, $this->config_text->get('antiadblock_ini_'.$mi_lng));
        $variable['lng_take_help']          = $this->config_text->get('antiadblock_help_'.$mi_lng);
        $variable['lng_take_help_url']      = $this->config_text->get('antiadblock_help_url_'.$mi_lng);
        $variable['lng_request_disable']    = str_ireplace($buscar, $reemplazar, $this->config_text->get('antiadblock_disable_'.$mi_lng));
        $variable['lng_close_over']         = $this->config_text->get('antiadblock_over_'.$mi_lng);

        $this->template->assign_vars(array(
            'ANTIADBLOCK_ACTIVE'            => $config['antiadblock_active'],
            'ANTIADBLOCK_ETIQ_1'            => $eti_noscript,
            'ANTIADBLOCK_LAYER_ID'          => $layer_id,
            'ANTIADBLOCK_MODO'              => $config['antiadblock_banner'],
            'ANTIADBLOCK_COOKIE'            => $show,
            'ANTIADBLOCK_VARS'              => urlencode(serialize($variable)),
            'ANTIADBLOCK_REQUEST_INI'       => $variable['lng_request_ini'],
            'ANTIADBLOCK_TAKE_HELP'         => $variable['lng_take_help'],
            'ANTIADBLOCK_TAKE_HELP_URL'     => $variable['lng_take_help_url'],
            'ANTIADBLOCK_REQUEST_DISABLE'   => $variable['lng_request_disable'],
        ));
    }

    /**
    * Validate input text of %config_text
    *
    * @param \phpbb\event\data $event The event object
    * @return void
    * @access public
    */
    public function validate_config_variable($event)
    {
        $cadena = $this->config_text->get('antiadblock_languages');
        $idiomas = !empty($cadena) ? unserialize(json_decode($cadena, true)) : array();
        $idiomas[] = 'new';

        $error = $event['error'];

        foreach ($idiomas as $i)
        {
            $input = isset($event['cfg_array']['antiadblock_ini_'.$i]) ? $event['cfg_array']['antiadblock_ini_'.$i] : '';

            // Check if the validate test is for antiadblock_ini
            if ($event['config_definition']['validate'] === 'antiadblock_ini_'.$i)
            {
                if (strlen($input) > 550 || strlen($input) == 0)
                {
                    $error[] = $this->user->lang('ACP_DISPLAY_ANTIADBLOCK_ID_INVALID_TIT', strlen($input), $this->user->lang('ACP_ANTIADBLOCK_REQUEST_INI'), $i);
                }
            }

            $input = isset($event['cfg_array']['antiadblock_disable_'.$i]) ? $event['cfg_array']['antiadblock_disable_'.$i] : '';
            if ($input !== '')
            {
                // Check if the validate test is for antiadblock_disable_
                if ($event['config_definition']['validate'] === 'antiadblock_disable_'.$i)
                {
                    if (strlen($input) > 550)
                    {
                        $error[] = $this->user->lang('ACP_DISPLAY_ANTIADBLOCK_ID_INVALID_DIS', strlen($input), $this->user->lang('ACP_ANTIADBLOCK_REQUEST_DISABLE'), $i);
                    }
                }
            }
        }

        // // Update error event data
        $event['error'] = $error;
    }

    /**
    * ACP fonction : Select method
    *
    * @param object $event The event object
    *
    * @return null
    * @access public
    */
    public function build_config_template($event)
    {
        global $config;

        if ($event['key'] == 'antiadblock_banner')
        {
            $event['tpl'] = '<select id="antiadblock_banner" name="config[antiadblock_banner]"><option value="1"' . (($config['antiadblock_banner'] == 1) ? ' selected="selected"' : '') . '>' . $this->user->lang['ACP_ANTIADBLOCK_SCREEN'] . '</option><option value="2"' . (($config['antiadblock_banner'] == 2) ? ' selected="selected"' : '') . '>' . $this->user->lang['ACP_ANTIADBLOCK_BANNER'] . '</option><option value="3"' . (($config['antiadblock_banner'] == 3) ? ' selected="selected"' : '') . '>' . $this->user->lang['ACP_ANTIADBLOCK_MESSAGE'] . '</option></select>';
        }
    }

    // Show permissions
    public function permissions($event)
    {
        $permissions = $event['permissions'];
        $permissions += array(
            'u_show_antiadblock'    => array(
                        'lang'      => 'ACL_U_SHOW_ANTIADBLOCK',
                        'cat'       => 'antiadblock'
            ),
            'f_show_antiadblock'    => array(
                        'lang'      => 'ACL_F_SHOW_ANTIADBLOCK',
                        'cat'       => 'antiadblock'
            ),
        );
        $event['permissions'] = $permissions;
        $categories['antiadblock'] = 'ACL_CAT_ANTIADBLOCK';
        $event['categories'] = array_merge($event['categories'], $categories);
    }
}
?>